@@ -1,6 +1,7 @@
 package ZooKeeper::Watcher;
 use ZooKeeper::XS;
 use Moo;
+use namespace::autoclean;
 
 =head1 NAME
 
@@ -43,20 +44,6 @@ has cb => (
     required => 1,
 );
 
-=head1 METHODS
-
-=head2 trigger
-
-Manually trigger an event on a watch.
-
-=cut
-
-around trigger => sub {
-    my ($orig, $self, $event) = @_;
-    my ($path, $state, $type) = @{$event}{qw(path state type)};
-    return $self->$orig($path//"", $state//0, $type//0);
-};
-
 sub BUILD {
     my ($self) = @_;
     $self->_xs_init($self->dispatcher, $self->cb);
